/*
 * Copyright (C) 2004 Fernando Herrera <fherrera@onirica.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections;

using Mono.Posix;

using Gtk;
using GLib;

namespace Muine.Plugins.Burn {

    public class BurnPrefs
    {
        [Glade.Widget]
        Window window;
        [Glade.Widget]
        OptionMenu drives_menu;

        private ArrayList devices;

        
        public BurnPrefs (ArrayList devices) 
        {
            Glade.XML gxml = new Glade.XML (null, "BurnPrefs.glade", "window", null);
            gxml.Autoconnect (this);

            this.devices = (ArrayList) devices.Clone ();

            window.Title = string.Format (Catalog.GetString ("Burn playlist"));

            window.SetDefaultSize (400, -1);
            Menu m = new Menu ();
            foreach (CdUnit unit in devices) {
                MenuItem item = new MenuItem (unit.Name);
                m.Append (item);
            }
            drives_menu.Menu = m;
            drives_menu.ShowAll ();
            try {
                string path = (string) Config.Get ("/apps/muine/burn/drive");
                for (int i = 0; i < devices.Count; i++) {
                    CdUnit unit = (CdUnit) devices[i];
                    if (unit.Path == path)
                        drives_menu.SetHistory ((uint) i);
                }
            } catch {
                drives_menu.SetHistory (0);
            }
        }

        public bool GetDrivePath (out string drive_path)
        {
            int res = ((Dialog) window).Run ();

            if (res == (int) ResponseType.Ok) {
                CdUnit unit = (CdUnit) devices[(int) drives_menu.History];
                drive_path = unit.Path;
                Config.Set ("/apps/muine/burn/drive", drive_path);
                window.Destroy ();
                return true;
            } else {
                drive_path = null;
                window.Destroy ();
                return false;
            }
        }

    }
}
