/*
 * Copyright (C) 2004 Jorn Baayen <jorn@nl.linux.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using System;

using Gtk;
using GLib;

namespace Muine.Plugins.Burn {

    public class ProgressWindow
    {
        [Glade.Widget]
        public Window window;
        [Glade.Widget]
        Label loading_label;
        [Glade.Widget]
        Container file_label_container;
        [Glade.Widget]
        ProgressBar progressbar;
        private Label file_label;
        private int steps = 0;
        private int current_step = 0;

        bool canceled;
    
        public ProgressWindow (Window parent, string label, string title)
        {
            Glade.XML gxml = new Glade.XML (null, "ProgressWindow.glade", "window", null);
            gxml.Autoconnect (this);

            window.TransientFor = parent;
            window.Title = string.Format (title);

            window.SetDefaultSize (400, -1);

            file_label = new Label ("");
            file_label.Xalign = 0.0f;
            file_label.Visible = true;
            file_label.Ellipsize = Pango.EllipsizeMode.End;
            file_label_container.Add (file_label);

            loading_label.Markup = "<b>" + label + "</b>";
            canceled = false;

            file_label.Text = "...";

            while (MainContext.Pending ())
                Main.Iteration ();
        }

        public bool ReportFile (string file)
        {
            if (canceled)
                return false;

            window.Visible = true;

            file_label.Text = file;

            while (MainContext.Pending ())
                Main.Iteration ();

            return true;
        }

        public int TotalSteps {
            set {
                steps = value;
            }
            get {
                return steps;
            }
        }

        public double Fraction {
            set {
                progressbar.Fraction = value;
            }
            get {
                return progressbar.Fraction;
            }
        }

        public string Label {
            set {
                loading_label.Text = string.Format (value);
            }
            get {
                return loading_label.Text;
            }
        }

        public void Step ()
        {
            current_step += 1;
            progressbar.Fraction = (double) current_step / steps;
        }

        public void Done ()
        {
            window.Destroy ();
        }

        private void HandleWindowResponse (object o, EventArgs a)
        {
            window.Visible = false;

            canceled = true;
        }

        private void HandleWindowDeleteEvent (object o, EventArgs a)
        {
            window.Visible = false;

            DeleteEventArgs args = (DeleteEventArgs) a;

            args.RetVal = true;

            canceled = true;
        }
    }
}
