/* -*- mode: C; c-file-style: "gnu" -*- */
/*
 * Copyright (C) 2004 Fernando Herrera <fherrera@onirica.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __RECORDER_H__
#define __RECORDER_H__

#include <glib-object.h>

#define TYPE_RECORDER            (recorder_get_type ())
#define RECORDER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RECORDER, Recorder))
#define RECORDER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RECORDER, RecorderClass))
#define IS_RECORDER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RECORDER))
#define IS_RECORDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RECORDER))
#define RECORDER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RECORDER, RecorderClass))

typedef struct _Recorder      Recorder;
typedef struct _RecorderClass RecorderClass;
typedef struct _RecorderPriv  RecorderPriv;

struct _Recorder
{
  GObject parent;
  RecorderPriv *priv;
};

struct _RecorderClass
{
  GObjectClass parent_class;
};


GType         recorder_get_type          (void);
Recorder *    recorder_new               (char **error);
gboolean      recorder_set_orig          (Recorder     *recorder,
				         const char *filename,
				         char      **error);
gboolean      recorder_set_dest          (Recorder     *recorder,
				         const char *filename,
				         char      **error);
void          recorder_write_file        (Recorder     *recorder);
void          recorder_write_file_cancel (Recorder     *recorder);
gboolean      recorder_add_track          (Recorder     *recorder,
				         const char *filename,
				         char      **error);
gchar *       recorder_get_valid_devices  (void);
gboolean      recorder_has_many_devices  (void);
gboolean      recorder_select_drive      (Recorder     *recorder,
				         const char *device,
				         char      **error);

gint64        recorder_get_media_size    (Recorder *recorder);

int           recorder_burn_cd           (Recorder     *recorder);
void          recorder_pause             (Recorder     *recorder);
int           recorder_tell              (Recorder     *recorder);
unsigned long long get_dir_free_space         (char *path);

#endif /* __RECORDER_H__ */
